Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterServ ¶
func RegisterServ(n comm.MoLingServerType, f abstract.ServiceFactory)
RegisterServ register service
func ServiceList ¶
func ServiceList() map[comm.MoLingServerType]abstract.ServiceFactory
ServiceList get service lists
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package services provides a set of services for the MoLing application.
|
Package services provides a set of services for the MoLing application. |
|
Package services Description: This file contains the implementation of the CommandServer interface for macOS and Linux.
|
Package services Description: This file contains the implementation of the CommandServer interface for macOS and Linux. |
|
Package services provides the implementation of the FileSystemServer, which allows access to files and directories on the local file system.
|
Package services provides the implementation of the FileSystemServer, which allows access to files and directories on the local file system. |
Click to show internal directories.
Click to hide internal directories.